/* PassphraseDialog.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from PassphraseDialog.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <adwaita.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include "deja.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_PASSPHRASE_DIALOG (passphrase_dialog_get_type ())
#define PASSPHRASE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PASSPHRASE_DIALOG, PassphraseDialog))
#define PASSPHRASE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PASSPHRASE_DIALOG, PassphraseDialogClass))
#define IS_PASSPHRASE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PASSPHRASE_DIALOG))
#define IS_PASSPHRASE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PASSPHRASE_DIALOG))
#define PASSPHRASE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PASSPHRASE_DIALOG, PassphraseDialogClass))

typedef struct _PassphraseDialog PassphraseDialog;
typedef struct _PassphraseDialogClass PassphraseDialogClass;
typedef struct _PassphraseDialogPrivate PassphraseDialogPrivate;

#define TYPE_SWITCH_ROW (switch_row_get_type ())
#define SWITCH_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SWITCH_ROW, SwitchRow))
#define SWITCH_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SWITCH_ROW, SwitchRowClass))
#define IS_SWITCH_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SWITCH_ROW))
#define IS_SWITCH_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SWITCH_ROW))
#define SWITCH_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SWITCH_ROW, SwitchRowClass))

typedef struct _SwitchRow SwitchRow;
typedef struct _SwitchRowClass SwitchRowClass;
enum  {
	PASSPHRASE_DIALOG_0_PROPERTY,
	PASSPHRASE_DIALOG_LABEL_PROPERTY,
	PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY,
	PASSPHRASE_DIALOG_NAG_MODE_PROPERTY,
	PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY,
	PASSPHRASE_DIALOG_REMEMBER_PROPERTY,
	PASSPHRASE_DIALOG_NUM_PROPERTIES
};
static GParamSpec* passphrase_dialog_properties[PASSPHRASE_DIALOG_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _PassphraseDialog {
	AdwAlertDialog parent_instance;
	PassphraseDialogPrivate * priv;
};

struct _PassphraseDialogClass {
	AdwAlertDialogClass parent_class;
};

struct _PassphraseDialogPrivate {
	gchar* _label;
	gboolean _first_time;
	gboolean _nag_mode;
	gchar* _passphrase;
	gboolean _remember;
	SwitchRow* use_password;
	AdwPasswordEntryRow* entry;
	AdwPasswordEntryRow* confirm;
	SwitchRow* nag_switch;
};

static gint PassphraseDialog_private_offset;
static gpointer passphrase_dialog_parent_class = NULL;

VALA_EXTERN GType passphrase_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PassphraseDialog, g_object_unref)
VALA_EXTERN GType switch_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SwitchRow, g_object_unref)
static void passphrase_dialog_update_responses (PassphraseDialog* self);
VALA_EXTERN gboolean switch_row_get_active (SwitchRow* self);
static void _passphrase_dialog_update_responses_gtk_editable_changed (GtkEditable* _sender,
                                                               gpointer self);
static void passphrase_dialog_update_nag (PassphraseDialog* self);
VALA_EXTERN PassphraseDialog* passphrase_dialog_new (void);
VALA_EXTERN PassphraseDialog* passphrase_dialog_construct (GType object_type);
VALA_EXTERN const gchar* passphrase_dialog_get_label (PassphraseDialog* self);
VALA_EXTERN void passphrase_dialog_set_label (PassphraseDialog* self,
                                  const gchar* value);
VALA_EXTERN gboolean passphrase_dialog_get_first_time (PassphraseDialog* self);
VALA_EXTERN void passphrase_dialog_set_first_time (PassphraseDialog* self,
                                       gboolean value);
VALA_EXTERN gboolean passphrase_dialog_get_nag_mode (PassphraseDialog* self);
VALA_EXTERN void passphrase_dialog_set_nag_mode (PassphraseDialog* self,
                                     gboolean value);
VALA_EXTERN const gchar* passphrase_dialog_get_passphrase (PassphraseDialog* self);
VALA_EXTERN void passphrase_dialog_set_passphrase (PassphraseDialog* self,
                                       const gchar* value);
VALA_EXTERN gboolean passphrase_dialog_get_remember (PassphraseDialog* self);
VALA_EXTERN void passphrase_dialog_set_remember (PassphraseDialog* self,
                                     gboolean value);
static GObject * passphrase_dialog_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties);
static void _passphrase_dialog_update_responses_g_object_notify (GObject* _sender,
                                                          GParamSpec* pspec,
                                                          gpointer self);
static void _passphrase_dialog_update_nag_g_object_notify (GObject* _sender,
                                                    GParamSpec* pspec,
                                                    gpointer self);
static void passphrase_dialog_finalize (GObject * obj);
static GType passphrase_dialog_get_type_once (void);
static void _vala_passphrase_dialog_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_passphrase_dialog_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);

static inline gpointer
passphrase_dialog_get_instance_private (PassphraseDialog* self)
{
	return G_STRUCT_MEMBER_P (self, PassphraseDialog_private_offset);
}

static void
passphrase_dialog_update_responses (PassphraseDialog* self)
{
	gboolean _tmp0_ = FALSE;
	AdwPasswordEntryRow* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean confirm_valid = FALSE;
	gboolean _tmp12_ = FALSE;
	SwitchRow* _tmp13_;
	gboolean _tmp14_;
	gboolean _tmp15_;
	gboolean can_continue = FALSE;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->confirm;
	_tmp2_ = gtk_widget_get_visible ((GtkWidget*) _tmp1_);
	_tmp3_ = _tmp2_;
	if (!_tmp3_) {
		_tmp0_ = TRUE;
	} else {
		AdwPasswordEntryRow* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		AdwPasswordEntryRow* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		_tmp4_ = self->priv->entry;
		_tmp5_ = gtk_editable_get_text ((GtkEditable*) _tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = self->priv->confirm;
		_tmp8_ = gtk_editable_get_text ((GtkEditable*) _tmp7_);
		_tmp9_ = _tmp8_;
		_tmp0_ = g_strcmp0 (_tmp6_, _tmp9_) == 0;
	}
	confirm_valid = _tmp0_;
	if (confirm_valid) {
		AdwPasswordEntryRow* _tmp10_;
		_tmp10_ = self->priv->confirm;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp10_, "error");
	} else {
		AdwPasswordEntryRow* _tmp11_;
		_tmp11_ = self->priv->confirm;
		gtk_widget_add_css_class ((GtkWidget*) _tmp11_, "error");
	}
	_tmp13_ = self->priv->use_password;
	_tmp14_ = switch_row_get_active (_tmp13_);
	_tmp15_ = _tmp14_;
	if (!_tmp15_) {
		_tmp12_ = TRUE;
	} else {
		gboolean _tmp16_ = FALSE;
		AdwPasswordEntryRow* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		_tmp17_ = self->priv->entry;
		_tmp18_ = gtk_editable_get_text ((GtkEditable*) _tmp17_);
		_tmp19_ = _tmp18_;
		if (g_strcmp0 (_tmp19_, "") != 0) {
			_tmp16_ = confirm_valid;
		} else {
			_tmp16_ = FALSE;
		}
		_tmp12_ = _tmp16_;
	}
	can_continue = _tmp12_;
	adw_alert_dialog_set_response_enabled ((AdwAlertDialog*) self, "continue", can_continue);
}

static void
_passphrase_dialog_update_responses_gtk_editable_changed (GtkEditable* _sender,
                                                          gpointer self)
{
	passphrase_dialog_update_responses ((PassphraseDialog*) self);
}

static void
passphrase_dialog_update_nag (PassphraseDialog* self)
{
	SwitchRow* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->nag_switch;
	_tmp1_ = switch_row_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	deja_dup_update_nag_time (!_tmp2_);
}

PassphraseDialog*
passphrase_dialog_construct (GType object_type)
{
	PassphraseDialog * self = NULL;
	self = (PassphraseDialog*) g_object_new (object_type, NULL);
	return self;
}

PassphraseDialog*
passphrase_dialog_new (void)
{
	return passphrase_dialog_construct (TYPE_PASSPHRASE_DIALOG);
}

const gchar*
passphrase_dialog_get_label (PassphraseDialog* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_label;
	result = _tmp0_;
	return result;
}

void
passphrase_dialog_set_label (PassphraseDialog* self,
                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = passphrase_dialog_get_label (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_label);
		self->priv->_label = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, passphrase_dialog_properties[PASSPHRASE_DIALOG_LABEL_PROPERTY]);
	}
}

gboolean
passphrase_dialog_get_first_time (PassphraseDialog* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_first_time;
	return result;
}

void
passphrase_dialog_set_first_time (PassphraseDialog* self,
                                  gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = passphrase_dialog_get_first_time (self);
	if (old_value != value) {
		self->priv->_first_time = value;
		g_object_notify_by_pspec ((GObject *) self, passphrase_dialog_properties[PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY]);
	}
}

gboolean
passphrase_dialog_get_nag_mode (PassphraseDialog* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_nag_mode;
	return result;
}

void
passphrase_dialog_set_nag_mode (PassphraseDialog* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = passphrase_dialog_get_nag_mode (self);
	if (old_value != value) {
		self->priv->_nag_mode = value;
		g_object_notify_by_pspec ((GObject *) self, passphrase_dialog_properties[PASSPHRASE_DIALOG_NAG_MODE_PROPERTY]);
	}
}

const gchar*
passphrase_dialog_get_passphrase (PassphraseDialog* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_passphrase;
	result = _tmp0_;
	return result;
}

void
passphrase_dialog_set_passphrase (PassphraseDialog* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = passphrase_dialog_get_passphrase (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_passphrase);
		self->priv->_passphrase = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, passphrase_dialog_properties[PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY]);
	}
}

gboolean
passphrase_dialog_get_remember (PassphraseDialog* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_remember;
	return result;
}

void
passphrase_dialog_set_remember (PassphraseDialog* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = passphrase_dialog_get_remember (self);
	if (old_value != value) {
		self->priv->_remember = value;
		g_object_notify_by_pspec ((GObject *) self, passphrase_dialog_properties[PASSPHRASE_DIALOG_REMEMBER_PROPERTY]);
	}
}

static void
_passphrase_dialog_update_responses_g_object_notify (GObject* _sender,
                                                     GParamSpec* pspec,
                                                     gpointer self)
{
	passphrase_dialog_update_responses ((PassphraseDialog*) self);
}

static void
_passphrase_dialog_update_nag_g_object_notify (GObject* _sender,
                                               GParamSpec* pspec,
                                               gpointer self)
{
	passphrase_dialog_update_nag ((PassphraseDialog*) self);
}

static GObject *
passphrase_dialog_constructor (GType type,
                               guint n_construct_properties,
                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	PassphraseDialog * self;
	SwitchRow* _tmp0_;
	SwitchRow* _tmp1_;
	parent_class = G_OBJECT_CLASS (passphrase_dialog_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PASSPHRASE_DIALOG, PassphraseDialog);
	_tmp0_ = self->priv->use_password;
	g_signal_connect_object ((GObject*) _tmp0_, "notify::active", (GCallback) _passphrase_dialog_update_responses_g_object_notify, self, 0);
	_tmp1_ = self->priv->nag_switch;
	g_signal_connect_object ((GObject*) _tmp1_, "notify::active", (GCallback) _passphrase_dialog_update_nag_g_object_notify, self, 0);
	return obj;
}

static void
passphrase_dialog_class_init (PassphraseDialogClass * klass,
                              gpointer klass_data)
{
	passphrase_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &PassphraseDialog_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_passphrase_dialog_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_passphrase_dialog_set_property;
	G_OBJECT_CLASS (klass)->constructor = passphrase_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = passphrase_dialog_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), PASSPHRASE_DIALOG_LABEL_PROPERTY, passphrase_dialog_properties[PASSPHRASE_DIALOG_LABEL_PROPERTY] = g_param_spec_string ("label", "label", "label", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY, passphrase_dialog_properties[PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY] = g_param_spec_boolean ("first-time", "first-time", "first-time", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PASSPHRASE_DIALOG_NAG_MODE_PROPERTY, passphrase_dialog_properties[PASSPHRASE_DIALOG_NAG_MODE_PROPERTY] = g_param_spec_boolean ("nag-mode", "nag-mode", "nag-mode", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY, passphrase_dialog_properties[PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY] = g_param_spec_string ("passphrase", "passphrase", "passphrase", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), PASSPHRASE_DIALOG_REMEMBER_PROPERTY, passphrase_dialog_properties[PASSPHRASE_DIALOG_REMEMBER_PROPERTY] = g_param_spec_boolean ("remember", "remember", "remember", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/PassphraseDialog.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "use_password", FALSE, PassphraseDialog_private_offset + G_STRUCT_OFFSET (PassphraseDialogPrivate, use_password));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "entry", FALSE, PassphraseDialog_private_offset + G_STRUCT_OFFSET (PassphraseDialogPrivate, entry));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "confirm", FALSE, PassphraseDialog_private_offset + G_STRUCT_OFFSET (PassphraseDialogPrivate, confirm));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "nag_switch", FALSE, PassphraseDialog_private_offset + G_STRUCT_OFFSET (PassphraseDialogPrivate, nag_switch));
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "update_responses", G_CALLBACK(_passphrase_dialog_update_responses_gtk_editable_changed));
}

static void
passphrase_dialog_instance_init (PassphraseDialog * self,
                                 gpointer klass)
{
	self->priv = passphrase_dialog_get_instance_private (self);
	g_type_ensure (TYPE_SWITCH_ROW);
	g_type_ensure (TYPE_SWITCH_ROW);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
passphrase_dialog_finalize (GObject * obj)
{
	PassphraseDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PASSPHRASE_DIALOG, PassphraseDialog);
	g_debug ("PassphraseDialog.vala:34: Finalizing PassphraseDialog\n");
	_g_free0 (self->priv->_label);
	_g_free0 (self->priv->_passphrase);
	G_OBJECT_CLASS (passphrase_dialog_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
passphrase_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PassphraseDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) passphrase_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PassphraseDialog), 0, (GInstanceInitFunc) passphrase_dialog_instance_init, NULL };
	GType passphrase_dialog_type_id;
	passphrase_dialog_type_id = g_type_register_static (adw_alert_dialog_get_type (), "PassphraseDialog", &g_define_type_info, 0);
	PassphraseDialog_private_offset = g_type_add_instance_private (passphrase_dialog_type_id, sizeof (PassphraseDialogPrivate));
	return passphrase_dialog_type_id;
}

GType
passphrase_dialog_get_type (void)
{
	static gsize passphrase_dialog_type_id__once = 0;
	if (g_once_init_enter (&passphrase_dialog_type_id__once)) {
		GType passphrase_dialog_type_id;
		passphrase_dialog_type_id = passphrase_dialog_get_type_once ();
		g_once_init_leave (&passphrase_dialog_type_id__once, passphrase_dialog_type_id);
	}
	return passphrase_dialog_type_id__once;
}

static void
_vala_passphrase_dialog_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	PassphraseDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PASSPHRASE_DIALOG, PassphraseDialog);
	switch (property_id) {
		case PASSPHRASE_DIALOG_LABEL_PROPERTY:
		g_value_set_string (value, passphrase_dialog_get_label (self));
		break;
		case PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY:
		g_value_set_boolean (value, passphrase_dialog_get_first_time (self));
		break;
		case PASSPHRASE_DIALOG_NAG_MODE_PROPERTY:
		g_value_set_boolean (value, passphrase_dialog_get_nag_mode (self));
		break;
		case PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY:
		g_value_set_string (value, passphrase_dialog_get_passphrase (self));
		break;
		case PASSPHRASE_DIALOG_REMEMBER_PROPERTY:
		g_value_set_boolean (value, passphrase_dialog_get_remember (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_passphrase_dialog_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	PassphraseDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_PASSPHRASE_DIALOG, PassphraseDialog);
	switch (property_id) {
		case PASSPHRASE_DIALOG_LABEL_PROPERTY:
		passphrase_dialog_set_label (self, g_value_get_string (value));
		break;
		case PASSPHRASE_DIALOG_FIRST_TIME_PROPERTY:
		passphrase_dialog_set_first_time (self, g_value_get_boolean (value));
		break;
		case PASSPHRASE_DIALOG_NAG_MODE_PROPERTY:
		passphrase_dialog_set_nag_mode (self, g_value_get_boolean (value));
		break;
		case PASSPHRASE_DIALOG_PASSPHRASE_PROPERTY:
		passphrase_dialog_set_passphrase (self, g_value_get_string (value));
		break;
		case PASSPHRASE_DIALOG_REMEMBER_PROPERTY:
		passphrase_dialog_set_remember (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

