/* ConfigIncludeFolderGroup.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from ConfigIncludeFolderGroup.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <adwaita.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_CONFIG_FOLDER_GROUP (config_folder_group_get_type ())
#define CONFIG_FOLDER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIG_FOLDER_GROUP, ConfigFolderGroup))
#define CONFIG_FOLDER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIG_FOLDER_GROUP, ConfigFolderGroupClass))
#define IS_CONFIG_FOLDER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIG_FOLDER_GROUP))
#define IS_CONFIG_FOLDER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIG_FOLDER_GROUP))
#define CONFIG_FOLDER_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIG_FOLDER_GROUP, ConfigFolderGroupClass))

typedef struct _ConfigFolderGroup ConfigFolderGroup;
typedef struct _ConfigFolderGroupClass ConfigFolderGroupClass;
typedef struct _ConfigFolderGroupPrivate ConfigFolderGroupPrivate;

#define TYPE_CONFIG_INCLUDE_FOLDER_GROUP (config_include_folder_group_get_type ())
#define CONFIG_INCLUDE_FOLDER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIG_INCLUDE_FOLDER_GROUP, ConfigIncludeFolderGroup))
#define CONFIG_INCLUDE_FOLDER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIG_INCLUDE_FOLDER_GROUP, ConfigIncludeFolderGroupClass))
#define IS_CONFIG_INCLUDE_FOLDER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIG_INCLUDE_FOLDER_GROUP))
#define IS_CONFIG_INCLUDE_FOLDER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIG_INCLUDE_FOLDER_GROUP))
#define CONFIG_INCLUDE_FOLDER_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIG_INCLUDE_FOLDER_GROUP, ConfigIncludeFolderGroupClass))

typedef struct _ConfigIncludeFolderGroup ConfigIncludeFolderGroup;
typedef struct _ConfigIncludeFolderGroupClass ConfigIncludeFolderGroupClass;
typedef struct _ConfigIncludeFolderGroupPrivate ConfigIncludeFolderGroupPrivate;
enum  {
	CONFIG_INCLUDE_FOLDER_GROUP_0_PROPERTY,
	CONFIG_INCLUDE_FOLDER_GROUP_NUM_PROPERTIES
};
static GParamSpec* config_include_folder_group_properties[CONFIG_INCLUDE_FOLDER_GROUP_NUM_PROPERTIES];

struct _ConfigFolderGroup {
	AdwPreferencesGroup parent_instance;
	ConfigFolderGroupPrivate * priv;
};

struct _ConfigFolderGroupClass {
	AdwPreferencesGroupClass parent_class;
};

struct _ConfigIncludeFolderGroup {
	ConfigFolderGroup parent_instance;
	ConfigIncludeFolderGroupPrivate * priv;
};

struct _ConfigIncludeFolderGroupClass {
	ConfigFolderGroupClass parent_class;
};

static gpointer config_include_folder_group_parent_class = NULL;

VALA_EXTERN GType config_folder_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ConfigFolderGroup, g_object_unref)
VALA_EXTERN GType config_include_folder_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ConfigIncludeFolderGroup, g_object_unref)
VALA_EXTERN ConfigIncludeFolderGroup* config_include_folder_group_new (void);
VALA_EXTERN ConfigIncludeFolderGroup* config_include_folder_group_construct (GType object_type);
VALA_EXTERN ConfigFolderGroup* config_folder_group_new (void);
VALA_EXTERN ConfigFolderGroup* config_folder_group_construct (GType object_type);
static GType config_include_folder_group_get_type_once (void);

ConfigIncludeFolderGroup*
config_include_folder_group_construct (GType object_type)
{
	ConfigIncludeFolderGroup * self = NULL;
	self = (ConfigIncludeFolderGroup*) config_folder_group_construct (object_type);
	return self;
}

ConfigIncludeFolderGroup*
config_include_folder_group_new (void)
{
	return config_include_folder_group_construct (TYPE_CONFIG_INCLUDE_FOLDER_GROUP);
}

static void
config_include_folder_group_class_init (ConfigIncludeFolderGroupClass * klass,
                                        gpointer klass_data)
{
	config_include_folder_group_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/ConfigIncludeFolderGroup.ui");
}

static void
config_include_folder_group_instance_init (ConfigIncludeFolderGroup * self,
                                           gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

 G_GNUC_NO_INLINE static GType
config_include_folder_group_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ConfigIncludeFolderGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) config_include_folder_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ConfigIncludeFolderGroup), 0, (GInstanceInitFunc) config_include_folder_group_instance_init, NULL };
	GType config_include_folder_group_type_id;
	config_include_folder_group_type_id = g_type_register_static (TYPE_CONFIG_FOLDER_GROUP, "ConfigIncludeFolderGroup", &g_define_type_info, 0);
	return config_include_folder_group_type_id;
}

GType
config_include_folder_group_get_type (void)
{
	static gsize config_include_folder_group_type_id__once = 0;
	if (g_once_init_enter (&config_include_folder_group_type_id__once)) {
		GType config_include_folder_group_type_id;
		config_include_folder_group_type_id = config_include_folder_group_get_type_once ();
		g_once_init_leave (&config_include_folder_group_type_id__once, config_include_folder_group_type_id);
	}
	return config_include_folder_group_type_id__once;
}

