/* ServerAddressHelp.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from ServerAddressHelp.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_SERVER_ADDRESS_HELP (server_address_help_get_type ())
#define SERVER_ADDRESS_HELP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERVER_ADDRESS_HELP, ServerAddressHelp))
#define SERVER_ADDRESS_HELP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERVER_ADDRESS_HELP, ServerAddressHelpClass))
#define IS_SERVER_ADDRESS_HELP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERVER_ADDRESS_HELP))
#define IS_SERVER_ADDRESS_HELP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERVER_ADDRESS_HELP))
#define SERVER_ADDRESS_HELP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERVER_ADDRESS_HELP, ServerAddressHelpClass))

typedef struct _ServerAddressHelp ServerAddressHelp;
typedef struct _ServerAddressHelpClass ServerAddressHelpClass;
typedef struct _ServerAddressHelpPrivate ServerAddressHelpPrivate;
enum  {
	SERVER_ADDRESS_HELP_0_PROPERTY,
	SERVER_ADDRESS_HELP_NUM_PROPERTIES
};
static GParamSpec* server_address_help_properties[SERVER_ADDRESS_HELP_NUM_PROPERTIES];
#define _pango_attr_list_unref0(var) ((var == NULL) ? NULL : (var = (pango_attr_list_unref (var), NULL)))

struct _ServerAddressHelp {
	GtkBox parent_instance;
	ServerAddressHelpPrivate * priv;
};

struct _ServerAddressHelpClass {
	GtkBoxClass parent_class;
};

struct _ServerAddressHelpPrivate {
	GtkLabel* address_header;
	GtkLabel* protocol_header;
	GtkLabel* prefix_header;
};

static gint ServerAddressHelp_private_offset;
static gpointer server_address_help_parent_class = NULL;

VALA_EXTERN GType server_address_help_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServerAddressHelp, g_object_unref)
VALA_EXTERN ServerAddressHelp* server_address_help_new (void);
VALA_EXTERN ServerAddressHelp* server_address_help_construct (GType object_type);
static GObject * server_address_help_constructor (GType type,
                                           guint n_construct_properties,
                                           GObjectConstructParam * construct_properties);
static void server_address_help_finalize (GObject * obj);
static GType server_address_help_get_type_once (void);

static inline gpointer
server_address_help_get_instance_private (ServerAddressHelp* self)
{
	return G_STRUCT_MEMBER_P (self, ServerAddressHelp_private_offset);
}

ServerAddressHelp*
server_address_help_construct (GType object_type)
{
	ServerAddressHelp * self = NULL;
	self = (ServerAddressHelp*) g_object_new (object_type, NULL);
	return self;
}

ServerAddressHelp*
server_address_help_new (void)
{
	return server_address_help_construct (TYPE_SERVER_ADDRESS_HELP);
}

static GObject *
server_address_help_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ServerAddressHelp * self;
	PangoAttrList* bold = NULL;
	PangoAttrList* _tmp0_;
	GtkLabel* _tmp1_;
	PangoAttrList* _tmp2_;
	GtkLabel* _tmp3_;
	PangoAttrList* _tmp4_;
	GtkLabel* _tmp5_;
	PangoAttrList* _tmp6_;
	parent_class = G_OBJECT_CLASS (server_address_help_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SERVER_ADDRESS_HELP, ServerAddressHelp);
	_tmp0_ = pango_attr_list_from_string ("weight bold");
	bold = _tmp0_;
	_tmp1_ = self->priv->address_header;
	_tmp2_ = bold;
	gtk_label_set_attributes (_tmp1_, _tmp2_);
	_tmp3_ = self->priv->protocol_header;
	_tmp4_ = bold;
	gtk_label_set_attributes (_tmp3_, _tmp4_);
	_tmp5_ = self->priv->prefix_header;
	_tmp6_ = bold;
	gtk_label_set_attributes (_tmp5_, _tmp6_);
	_pango_attr_list_unref0 (bold);
	return obj;
}

static void
server_address_help_class_init (ServerAddressHelpClass * klass,
                                gpointer klass_data)
{
	server_address_help_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ServerAddressHelp_private_offset);
	G_OBJECT_CLASS (klass)->constructor = server_address_help_constructor;
	G_OBJECT_CLASS (klass)->finalize = server_address_help_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/ServerAddressHelp.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "address_header", FALSE, ServerAddressHelp_private_offset + G_STRUCT_OFFSET (ServerAddressHelpPrivate, address_header));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "protocol_header", FALSE, ServerAddressHelp_private_offset + G_STRUCT_OFFSET (ServerAddressHelpPrivate, protocol_header));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prefix_header", FALSE, ServerAddressHelp_private_offset + G_STRUCT_OFFSET (ServerAddressHelpPrivate, prefix_header));
}

static void
server_address_help_instance_init (ServerAddressHelp * self,
                                   gpointer klass)
{
	self->priv = server_address_help_get_instance_private (self);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
server_address_help_finalize (GObject * obj)
{
	ServerAddressHelp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SERVER_ADDRESS_HELP, ServerAddressHelp);
	G_OBJECT_CLASS (server_address_help_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
server_address_help_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ServerAddressHelpClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) server_address_help_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ServerAddressHelp), 0, (GInstanceInitFunc) server_address_help_instance_init, NULL };
	GType server_address_help_type_id;
	server_address_help_type_id = g_type_register_static (gtk_box_get_type (), "ServerAddressHelp", &g_define_type_info, 0);
	ServerAddressHelp_private_offset = g_type_add_instance_private (server_address_help_type_id, sizeof (ServerAddressHelpPrivate));
	return server_address_help_type_id;
}

GType
server_address_help_get_type (void)
{
	static gsize server_address_help_type_id__once = 0;
	if (g_once_init_enter (&server_address_help_type_id__once)) {
		GType server_address_help_type_id;
		server_address_help_type_id = server_address_help_get_type_once ();
		g_once_init_leave (&server_address_help_type_id__once, server_address_help_type_id);
	}
	return server_address_help_type_id__once;
}

