/* FirstBackupDialog.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from FirstBackupDialog.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <adwaita.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_ACTION_DIALOG (action_dialog_get_type ())
#define ACTION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ACTION_DIALOG, ActionDialog))
#define ACTION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ACTION_DIALOG, ActionDialogClass))
#define IS_ACTION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ACTION_DIALOG))
#define IS_ACTION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ACTION_DIALOG))
#define ACTION_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ACTION_DIALOG, ActionDialogClass))

typedef struct _ActionDialog ActionDialog;
typedef struct _ActionDialogClass ActionDialogClass;
typedef struct _ActionDialogPrivate ActionDialogPrivate;

#define TYPE_FIRST_BACKUP_DIALOG (first_backup_dialog_get_type ())
#define FIRST_BACKUP_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FIRST_BACKUP_DIALOG, FirstBackupDialog))
#define FIRST_BACKUP_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FIRST_BACKUP_DIALOG, FirstBackupDialogClass))
#define IS_FIRST_BACKUP_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FIRST_BACKUP_DIALOG))
#define IS_FIRST_BACKUP_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FIRST_BACKUP_DIALOG))
#define FIRST_BACKUP_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FIRST_BACKUP_DIALOG, FirstBackupDialogClass))

typedef struct _FirstBackupDialog FirstBackupDialog;
typedef struct _FirstBackupDialogClass FirstBackupDialogClass;
typedef struct _FirstBackupDialogPrivate FirstBackupDialogPrivate;
enum  {
	FIRST_BACKUP_DIALOG_0_PROPERTY,
	FIRST_BACKUP_DIALOG_NUM_PROPERTIES
};
static GParamSpec* first_backup_dialog_properties[FIRST_BACKUP_DIALOG_NUM_PROPERTIES];
enum  {
	FIRST_BACKUP_DIALOG_BACK_UP_SIGNAL,
	FIRST_BACKUP_DIALOG_NUM_SIGNALS
};
static guint first_backup_dialog_signals[FIRST_BACKUP_DIALOG_NUM_SIGNALS] = {0};

struct _ActionDialog {
	AdwDialog parent_instance;
	ActionDialogPrivate * priv;
};

struct _ActionDialogClass {
	AdwDialogClass parent_class;
	void (*accept) (ActionDialog* self);
};

struct _FirstBackupDialog {
	ActionDialog parent_instance;
	FirstBackupDialogPrivate * priv;
};

struct _FirstBackupDialogClass {
	ActionDialogClass parent_class;
};

static gpointer first_backup_dialog_parent_class = NULL;

VALA_EXTERN GType action_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ActionDialog, g_object_unref)
VALA_EXTERN GType first_backup_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FirstBackupDialog, g_object_unref)
VALA_EXTERN void action_dialog_accept (ActionDialog* self);
static void first_backup_dialog_real_accept (ActionDialog* base);
VALA_EXTERN FirstBackupDialog* first_backup_dialog_new (void);
VALA_EXTERN FirstBackupDialog* first_backup_dialog_construct (GType object_type);
VALA_EXTERN ActionDialog* action_dialog_new (void);
VALA_EXTERN ActionDialog* action_dialog_construct (GType object_type);
static GType first_backup_dialog_get_type_once (void);

static void
first_backup_dialog_real_accept (ActionDialog* base)
{
	FirstBackupDialog * self;
	self = (FirstBackupDialog*) base;
	g_signal_emit (self, first_backup_dialog_signals[FIRST_BACKUP_DIALOG_BACK_UP_SIGNAL], 0);
}

FirstBackupDialog*
first_backup_dialog_construct (GType object_type)
{
	FirstBackupDialog * self = NULL;
	self = (FirstBackupDialog*) action_dialog_construct (object_type);
	return self;
}

FirstBackupDialog*
first_backup_dialog_new (void)
{
	return first_backup_dialog_construct (TYPE_FIRST_BACKUP_DIALOG);
}

static void
first_backup_dialog_class_init (FirstBackupDialogClass * klass,
                                gpointer klass_data)
{
	first_backup_dialog_parent_class = g_type_class_peek_parent (klass);
	((ActionDialogClass *) klass)->accept = (void (*) (ActionDialog*)) first_backup_dialog_real_accept;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/FirstBackupDialog.ui");
	first_backup_dialog_signals[FIRST_BACKUP_DIALOG_BACK_UP_SIGNAL] = g_signal_new ("back-up", TYPE_FIRST_BACKUP_DIALOG, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
first_backup_dialog_instance_init (FirstBackupDialog * self,
                                   gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

 G_GNUC_NO_INLINE static GType
first_backup_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (FirstBackupDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) first_backup_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FirstBackupDialog), 0, (GInstanceInitFunc) first_backup_dialog_instance_init, NULL };
	GType first_backup_dialog_type_id;
	first_backup_dialog_type_id = g_type_register_static (TYPE_ACTION_DIALOG, "FirstBackupDialog", &g_define_type_info, 0);
	return first_backup_dialog_type_id;
}

GType
first_backup_dialog_get_type (void)
{
	static gsize first_backup_dialog_type_id__once = 0;
	if (g_once_init_enter (&first_backup_dialog_type_id__once)) {
		GType first_backup_dialog_type_id;
		first_backup_dialog_type_id = first_backup_dialog_get_type_once ();
		g_once_init_leave (&first_backup_dialog_type_id__once, first_backup_dialog_type_id);
	}
	return first_backup_dialog_type_id__once;
}

