/* OperationStatusPage.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from OperationStatusPage.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include "deja.h"
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_OPERATION_STATUS_PAGE (operation_status_page_get_type ())
#define OPERATION_STATUS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATION_STATUS_PAGE, OperationStatusPage))
#define OPERATION_STATUS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATION_STATUS_PAGE, OperationStatusPageClass))
#define IS_OPERATION_STATUS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATION_STATUS_PAGE))
#define IS_OPERATION_STATUS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATION_STATUS_PAGE))
#define OPERATION_STATUS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATION_STATUS_PAGE, OperationStatusPageClass))

typedef struct _OperationStatusPage OperationStatusPage;
typedef struct _OperationStatusPageClass OperationStatusPageClass;
typedef struct _OperationStatusPagePrivate OperationStatusPagePrivate;

#define TYPE_OPERATION_WRAPPER (operation_wrapper_get_type ())
#define OPERATION_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATION_WRAPPER, OperationWrapper))
#define OPERATION_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATION_WRAPPER, OperationWrapperClass))
#define IS_OPERATION_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATION_WRAPPER))
#define IS_OPERATION_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATION_WRAPPER))
#define OPERATION_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATION_WRAPPER, OperationWrapperClass))

typedef struct _OperationWrapper OperationWrapper;
typedef struct _OperationWrapperClass OperationWrapperClass;
enum  {
	OPERATION_STATUS_PAGE_0_PROPERTY,
	OPERATION_STATUS_PAGE_NUM_PROPERTIES
};
static GParamSpec* operation_status_page_properties[OPERATION_STATUS_PAGE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _OperationStatusPage {
	AdwBin parent_instance;
	OperationStatusPagePrivate * priv;
};

struct _OperationStatusPageClass {
	AdwBinClass parent_class;
};

struct _OperationStatusPagePrivate {
	GtkStack* stack;
	GtkLabel* spinner_label;
	GtkLabel* summary;
	GtkButton* button;
	OperationWrapper* wrapper;
};

static gint OperationStatusPage_private_offset;
static gpointer operation_status_page_parent_class = NULL;

VALA_EXTERN GType operation_status_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OperationStatusPage, g_object_unref)
VALA_EXTERN GType operation_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OperationWrapper, g_object_unref)
VALA_EXTERN void operation_status_page_connect_to_operation (OperationStatusPage* self,
                                                 DejaDupOperation* operation);
VALA_EXTERN OperationWrapper* operation_wrapper_new (DejaDupOperation* operation,
                                         GtkWidget* parent);
VALA_EXTERN OperationWrapper* operation_wrapper_construct (GType object_type,
                                               DejaDupOperation* operation,
                                               GtkWidget* parent);
static void operation_status_page_handle_button_label_change (OperationStatusPage* self);
static void _operation_status_page_handle_button_label_change_g_object_notify (GObject* _sender,
                                                                        GParamSpec* pspec,
                                                                        gpointer self);
static void operation_status_page_handle_button_suggested_change (OperationStatusPage* self);
static void _operation_status_page_handle_button_suggested_change_g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void operation_status_page_handle_error_mode_change (OperationStatusPage* self);
static void _operation_status_page_handle_error_mode_change_g_object_notify (GObject* _sender,
                                                                      GParamSpec* pspec,
                                                                      gpointer self);
static void operation_status_page_handle_pulsing_change (OperationStatusPage* self);
static void _operation_status_page_handle_pulsing_change_g_object_notify (GObject* _sender,
                                                                   GParamSpec* pspec,
                                                                   gpointer self);
static void operation_status_page_handle_done (OperationStatusPage* self);
static void _operation_status_page_handle_done_operation_wrapper_done (OperationWrapper* _sender,
                                                                gboolean cancelled,
                                                                gpointer self);
VALA_EXTERN void operation_status_page_set_error_state (OperationStatusPage* self,
                                            const gchar* message);
static void operation_status_page_handle_realize (OperationStatusPage* self);
static gboolean operation_status_page_handle_close_request (OperationStatusPage* self);
static gboolean _operation_status_page_handle_close_request_gtk_window_close_request (GtkWindow* _sender,
                                                                               gpointer self);
VALA_EXTERN DejaDupOperation* operation_wrapper_get_operation (OperationWrapper* self);
static void operation_status_page_on_button_clicked (OperationStatusPage* self);
VALA_EXTERN void operation_wrapper_click (OperationWrapper* self);
static void _operation_status_page_on_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self);
VALA_EXTERN void operation_wrapper_clear (OperationWrapper* self);
VALA_EXTERN const gchar* operation_wrapper_get_button_label (OperationWrapper* self);
VALA_EXTERN gboolean operation_wrapper_get_button_suggested (OperationWrapper* self);
VALA_EXTERN gboolean operation_wrapper_get_error_mode (OperationWrapper* self);
VALA_EXTERN gboolean operation_wrapper_get_pulsing (OperationWrapper* self);
VALA_EXTERN gboolean operation_wrapper_get_active (OperationWrapper* self);
VALA_EXTERN OperationStatusPage* operation_status_page_new (void);
VALA_EXTERN OperationStatusPage* operation_status_page_construct (GType object_type);
static GObject * operation_status_page_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties);
static void _operation_status_page_handle_realize_gtk_widget_realize (GtkWidget* _sender,
                                                               gpointer self);
static void operation_status_page_finalize (GObject * obj);
static GType operation_status_page_get_type_once (void);

static inline gpointer
operation_status_page_get_instance_private (OperationStatusPage* self)
{
	return G_STRUCT_MEMBER_P (self, OperationStatusPage_private_offset);
}

static void
_operation_status_page_handle_button_label_change_g_object_notify (GObject* _sender,
                                                                   GParamSpec* pspec,
                                                                   gpointer self)
{
	operation_status_page_handle_button_label_change ((OperationStatusPage*) self);
}

static void
_operation_status_page_handle_button_suggested_change_g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	operation_status_page_handle_button_suggested_change ((OperationStatusPage*) self);
}

static void
_operation_status_page_handle_error_mode_change_g_object_notify (GObject* _sender,
                                                                 GParamSpec* pspec,
                                                                 gpointer self)
{
	operation_status_page_handle_error_mode_change ((OperationStatusPage*) self);
}

static void
_operation_status_page_handle_pulsing_change_g_object_notify (GObject* _sender,
                                                              GParamSpec* pspec,
                                                              gpointer self)
{
	operation_status_page_handle_pulsing_change ((OperationStatusPage*) self);
}

static void
_operation_status_page_handle_done_operation_wrapper_done (OperationWrapper* _sender,
                                                           gboolean cancelled,
                                                           gpointer self)
{
	operation_status_page_handle_done ((OperationStatusPage*) self);
}

void
operation_status_page_connect_to_operation (OperationStatusPage* self,
                                            DejaDupOperation* operation)
{
	GtkStack* _tmp0_;
	OperationWrapper* _tmp1_;
	OperationWrapper* _tmp2_;
	GtkLabel* _tmp3_;
	OperationWrapper* _tmp4_;
	GtkLabel* _tmp5_;
	OperationWrapper* _tmp6_;
	GtkButton* _tmp7_;
	OperationWrapper* _tmp8_;
	OperationWrapper* _tmp9_;
	OperationWrapper* _tmp10_;
	OperationWrapper* _tmp11_;
	OperationWrapper* _tmp12_;
	OperationWrapper* _tmp13_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (operation != NULL);
	_tmp0_ = self->priv->stack;
	gtk_stack_set_visible_child_full (_tmp0_, "spinner", GTK_STACK_TRANSITION_TYPE_NONE);
	_tmp1_ = operation_wrapper_new (operation, (GtkWidget*) self);
	_g_object_unref0 (self->priv->wrapper);
	self->priv->wrapper = _tmp1_;
	_tmp2_ = self->priv->wrapper;
	_tmp3_ = self->priv->spinner_label;
	g_object_bind_property_with_closures ((GObject*) _tmp2_, "summary", (GObject*) _tmp3_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp4_ = self->priv->wrapper;
	_tmp5_ = self->priv->summary;
	g_object_bind_property_with_closures ((GObject*) _tmp4_, "summary", (GObject*) _tmp5_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp6_ = self->priv->wrapper;
	_tmp7_ = self->priv->button;
	g_object_bind_property_with_closures ((GObject*) _tmp6_, "button-label", (GObject*) _tmp7_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp8_ = self->priv->wrapper;
	g_signal_connect_object ((GObject*) _tmp8_, "notify::button-label", (GCallback) _operation_status_page_handle_button_label_change_g_object_notify, self, 0);
	_tmp9_ = self->priv->wrapper;
	g_signal_connect_object ((GObject*) _tmp9_, "notify::button-suggested", (GCallback) _operation_status_page_handle_button_suggested_change_g_object_notify, self, 0);
	_tmp10_ = self->priv->wrapper;
	g_signal_connect_object ((GObject*) _tmp10_, "notify::error-mode", (GCallback) _operation_status_page_handle_error_mode_change_g_object_notify, self, 0);
	_tmp11_ = self->priv->wrapper;
	g_signal_connect_object ((GObject*) _tmp11_, "notify::active", (GCallback) _operation_status_page_handle_pulsing_change_g_object_notify, self, 0);
	_tmp12_ = self->priv->wrapper;
	g_signal_connect_object ((GObject*) _tmp12_, "notify::pulsing", (GCallback) _operation_status_page_handle_pulsing_change_g_object_notify, self, 0);
	_tmp13_ = self->priv->wrapper;
	g_signal_connect_object (_tmp13_, "done", (GCallback) _operation_status_page_handle_done_operation_wrapper_done, self, 0);
}

void
operation_status_page_set_error_state (OperationStatusPage* self,
                                       const gchar* message)
{
	GtkLabel* _tmp0_;
	GtkLabel* _tmp1_;
	GtkButton* _tmp2_;
	GtkStack* _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (message != NULL);
	_g_object_unref0 (self->priv->wrapper);
	self->priv->wrapper = NULL;
	_tmp0_ = self->priv->summary;
	gtk_label_set_label (_tmp0_, message);
	_tmp1_ = self->priv->summary;
	gtk_widget_add_css_class ((GtkWidget*) _tmp1_, "error");
	_tmp2_ = self->priv->button;
	gtk_widget_set_visible ((GtkWidget*) _tmp2_, FALSE);
	_tmp3_ = self->priv->stack;
	gtk_stack_set_visible_child_full (_tmp3_, "action", GTK_STACK_TRANSITION_TYPE_NONE);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static gboolean
_operation_status_page_handle_close_request_gtk_window_close_request (GtkWindow* _sender,
                                                                      gpointer self)
{
	gboolean result;
	result = operation_status_page_handle_close_request ((OperationStatusPage*) self);
	return result;
}

static void
operation_status_page_handle_realize (OperationStatusPage* self)
{
	GtkWindow* window = NULL;
	GtkRoot* _tmp0_;
	GtkRoot* _tmp1_;
	GtkWindow* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = gtk_widget_get_root ((GtkWidget*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_window_get_type ()) ? ((GtkWindow*) _tmp1_) : NULL);
	window = _tmp2_;
	g_signal_connect_object (window, "close-request", (GCallback) _operation_status_page_handle_close_request_gtk_window_close_request, self, 0);
	_g_object_unref0 (window);
}

static gboolean
operation_status_page_handle_close_request (OperationStatusPage* self)
{
	gboolean _tmp0_ = FALSE;
	OperationWrapper* _tmp1_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp1_ = self->priv->wrapper;
	if (_tmp1_ != NULL) {
		OperationWrapper* _tmp2_;
		DejaDupOperation* _tmp3_;
		DejaDupOperation* _tmp4_;
		_tmp2_ = self->priv->wrapper;
		_tmp3_ = operation_wrapper_get_operation (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		OperationWrapper* _tmp5_;
		DejaDupOperation* _tmp6_;
		DejaDupOperation* _tmp7_;
		_tmp5_ = self->priv->wrapper;
		_tmp6_ = operation_wrapper_get_operation (_tmp5_);
		_tmp7_ = _tmp6_;
		deja_dup_operation_stop (_tmp7_);
	}
	result = FALSE;
	return result;
}

static void
operation_status_page_on_button_clicked (OperationStatusPage* self)
{
	OperationWrapper* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->wrapper;
	operation_wrapper_click (_tmp0_);
}

static void
_operation_status_page_on_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                             gpointer self)
{
	operation_status_page_on_button_clicked ((OperationStatusPage*) self);
}

static void
operation_status_page_handle_done (OperationStatusPage* self)
{
	OperationWrapper* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->wrapper;
	operation_wrapper_clear (_tmp0_);
}

static void
operation_status_page_handle_button_label_change (OperationStatusPage* self)
{
	GtkButton* _tmp0_;
	OperationWrapper* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->button;
	_tmp1_ = self->priv->wrapper;
	_tmp2_ = operation_wrapper_get_button_label (_tmp1_);
	_tmp3_ = _tmp2_;
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, g_strcmp0 (_tmp3_, "") != 0);
}

static void
operation_status_page_handle_button_suggested_change (OperationStatusPage* self)
{
	OperationWrapper* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->wrapper;
	_tmp1_ = operation_wrapper_get_button_suggested (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		GtkButton* _tmp3_;
		_tmp3_ = self->priv->button;
		gtk_widget_add_css_class ((GtkWidget*) _tmp3_, "suggested-action");
	} else {
		GtkButton* _tmp4_;
		_tmp4_ = self->priv->button;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp4_, "suggested-action");
	}
}

static void
operation_status_page_handle_error_mode_change (OperationStatusPage* self)
{
	OperationWrapper* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->wrapper;
	_tmp1_ = operation_wrapper_get_error_mode (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		GtkLabel* _tmp3_;
		_tmp3_ = self->priv->summary;
		gtk_widget_add_css_class ((GtkWidget*) _tmp3_, "error");
	} else {
		GtkLabel* _tmp4_;
		_tmp4_ = self->priv->summary;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp4_, "error");
	}
}

static void
operation_status_page_handle_pulsing_change (OperationStatusPage* self)
{
	gboolean _tmp0_ = FALSE;
	OperationWrapper* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->wrapper;
	_tmp2_ = operation_wrapper_get_pulsing (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		_tmp0_ = TRUE;
	} else {
		OperationWrapper* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
		_tmp4_ = self->priv->wrapper;
		_tmp5_ = operation_wrapper_get_active (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp0_ = !_tmp6_;
	}
	if (_tmp0_) {
		GtkStack* _tmp7_;
		_tmp7_ = self->priv->stack;
		gtk_stack_set_visible_child_name (_tmp7_, "spinner");
	} else {
		GtkStack* _tmp8_;
		_tmp8_ = self->priv->stack;
		gtk_stack_set_visible_child_name (_tmp8_, "action");
	}
}

OperationStatusPage*
operation_status_page_construct (GType object_type)
{
	OperationStatusPage * self = NULL;
	self = (OperationStatusPage*) g_object_new (object_type, NULL);
	return self;
}

OperationStatusPage*
operation_status_page_new (void)
{
	return operation_status_page_construct (TYPE_OPERATION_STATUS_PAGE);
}

static void
_operation_status_page_handle_realize_gtk_widget_realize (GtkWidget* _sender,
                                                          gpointer self)
{
	operation_status_page_handle_realize ((OperationStatusPage*) self);
}

static GObject *
operation_status_page_constructor (GType type,
                                   guint n_construct_properties,
                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	OperationStatusPage * self;
	parent_class = G_OBJECT_CLASS (operation_status_page_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION_STATUS_PAGE, OperationStatusPage);
	g_signal_connect_object ((GtkWidget*) self, "realize", (GCallback) _operation_status_page_handle_realize_gtk_widget_realize, self, 0);
	return obj;
}

static void
operation_status_page_class_init (OperationStatusPageClass * klass,
                                  gpointer klass_data)
{
	operation_status_page_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &OperationStatusPage_private_offset);
	G_OBJECT_CLASS (klass)->constructor = operation_status_page_constructor;
	G_OBJECT_CLASS (klass)->finalize = operation_status_page_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/OperationStatusPage.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "stack", FALSE, OperationStatusPage_private_offset + G_STRUCT_OFFSET (OperationStatusPagePrivate, stack));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "spinner_label", FALSE, OperationStatusPage_private_offset + G_STRUCT_OFFSET (OperationStatusPagePrivate, spinner_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "summary", FALSE, OperationStatusPage_private_offset + G_STRUCT_OFFSET (OperationStatusPagePrivate, summary));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "button", FALSE, OperationStatusPage_private_offset + G_STRUCT_OFFSET (OperationStatusPagePrivate, button));
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_button_clicked", G_CALLBACK(_operation_status_page_on_button_clicked_gtk_button_clicked));
}

static void
operation_status_page_instance_init (OperationStatusPage * self,
                                     gpointer klass)
{
	self->priv = operation_status_page_get_instance_private (self);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
operation_status_page_finalize (GObject * obj)
{
	OperationStatusPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION_STATUS_PAGE, OperationStatusPage);
	_g_object_unref0 (self->priv->wrapper);
	G_OBJECT_CLASS (operation_status_page_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
operation_status_page_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (OperationStatusPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operation_status_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (OperationStatusPage), 0, (GInstanceInitFunc) operation_status_page_instance_init, NULL };
	GType operation_status_page_type_id;
	operation_status_page_type_id = g_type_register_static (adw_bin_get_type (), "OperationStatusPage", &g_define_type_info, 0);
	OperationStatusPage_private_offset = g_type_add_instance_private (operation_status_page_type_id, sizeof (OperationStatusPagePrivate));
	return operation_status_page_type_id;
}

GType
operation_status_page_get_type (void)
{
	static gsize operation_status_page_type_id__once = 0;
	if (g_once_init_enter (&operation_status_page_type_id__once)) {
		GType operation_status_page_type_id;
		operation_status_page_type_id = operation_status_page_get_type_once ();
		g_once_init_leave (&operation_status_page_type_id__once, operation_status_page_type_id);
	}
	return operation_status_page_type_id__once;
}

