/* OperationMount.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from OperationMount.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include "deja.h"
#include <glib-object.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	DEJA_DUP_OPERATION_MOUNT_0_PROPERTY,
	DEJA_DUP_OPERATION_MOUNT_NUM_PROPERTIES
};
static GParamSpec* deja_dup_operation_mount_properties[DEJA_DUP_OPERATION_MOUNT_NUM_PROPERTIES];

static gpointer deja_dup_operation_mount_parent_class = NULL;

static GType deja_dup_operation_mount_get_type_once (void);

DejaDupOperationMount*
deja_dup_operation_mount_construct (GType object_type,
                                    DejaDupOperationState* state)
{
	DejaDupOperationMount * self = NULL;
	g_return_val_if_fail (state != NULL, NULL);
	self = (DejaDupOperationMount*) g_object_new (object_type, "mode", DEJA_DUP_TOOL_JOB_MODE_MOUNT, NULL);
	deja_dup_operation_set_state ((DejaDupOperation*) self, state);
	return self;
}

DejaDupOperationMount*
deja_dup_operation_mount_new (DejaDupOperationState* state)
{
	return deja_dup_operation_mount_construct (DEJA_DUP_TYPE_OPERATION_MOUNT, state);
}

static void
deja_dup_operation_mount_class_init (DejaDupOperationMountClass * klass,
                                     gpointer klass_data)
{
	deja_dup_operation_mount_parent_class = g_type_class_peek_parent (klass);
}

static void
deja_dup_operation_mount_instance_init (DejaDupOperationMount * self,
                                        gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
deja_dup_operation_mount_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DejaDupOperationMountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) deja_dup_operation_mount_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DejaDupOperationMount), 0, (GInstanceInitFunc) deja_dup_operation_mount_instance_init, NULL };
	GType deja_dup_operation_mount_type_id;
	deja_dup_operation_mount_type_id = g_type_register_static (DEJA_DUP_TYPE_OPERATION, "DejaDupOperationMount", &g_define_type_info, 0);
	return deja_dup_operation_mount_type_id;
}

GType
deja_dup_operation_mount_get_type (void)
{
	static gsize deja_dup_operation_mount_type_id__once = 0;
	if (g_once_init_enter (&deja_dup_operation_mount_type_id__once)) {
		GType deja_dup_operation_mount_type_id;
		deja_dup_operation_mount_type_id = deja_dup_operation_mount_get_type_once ();
		g_once_init_leave (&deja_dup_operation_mount_type_id__once, deja_dup_operation_mount_type_id);
	}
	return deja_dup_operation_mount_type_id__once;
}

