/* InstallEnvSnap.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from InstallEnvSnap.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include "deja.h"
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define DEJA_DUP_TYPE_INSTALL_ENV_SNAP (deja_dup_install_env_snap_get_type ())
#define DEJA_DUP_INSTALL_ENV_SNAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DEJA_DUP_TYPE_INSTALL_ENV_SNAP, DejaDupInstallEnvSnap))
#define DEJA_DUP_INSTALL_ENV_SNAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DEJA_DUP_TYPE_INSTALL_ENV_SNAP, DejaDupInstallEnvSnapClass))
#define DEJA_DUP_IS_INSTALL_ENV_SNAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DEJA_DUP_TYPE_INSTALL_ENV_SNAP))
#define DEJA_DUP_IS_INSTALL_ENV_SNAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DEJA_DUP_TYPE_INSTALL_ENV_SNAP))
#define DEJA_DUP_INSTALL_ENV_SNAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DEJA_DUP_TYPE_INSTALL_ENV_SNAP, DejaDupInstallEnvSnapClass))

typedef struct _DejaDupInstallEnvSnap DejaDupInstallEnvSnap;
typedef struct _DejaDupInstallEnvSnapClass DejaDupInstallEnvSnapClass;
typedef struct _DejaDupInstallEnvSnapPrivate DejaDupInstallEnvSnapPrivate;
enum  {
	DEJA_DUP_INSTALL_ENV_SNAP_0_PROPERTY,
	DEJA_DUP_INSTALL_ENV_SNAP_NUM_PROPERTIES
};
static GParamSpec* deja_dup_install_env_snap_properties[DEJA_DUP_INSTALL_ENV_SNAP_NUM_PROPERTIES];

struct _DejaDupInstallEnvSnap {
	DejaDupInstallEnv parent_instance;
	DejaDupInstallEnvSnapPrivate * priv;
};

struct _DejaDupInstallEnvSnapClass {
	DejaDupInstallEnvClass parent_class;
};

static gpointer deja_dup_install_env_snap_parent_class = NULL;

VALA_EXTERN GType deja_dup_install_env_snap_get_type (void) G_GNUC_CONST ;
static gchar* deja_dup_install_env_snap_real_get_name (DejaDupInstallEnv* base);
static gchar* deja_dup_install_env_snap_real_get_debug_info (DejaDupInstallEnv* base);
VALA_EXTERN DejaDupInstallEnvSnap* deja_dup_install_env_snap_new (void);
VALA_EXTERN DejaDupInstallEnvSnap* deja_dup_install_env_snap_construct (GType object_type);
static GType deja_dup_install_env_snap_get_type_once (void);

static gchar*
deja_dup_install_env_snap_real_get_name (DejaDupInstallEnv* base)
{
	DejaDupInstallEnvSnap * self;
	gchar* _tmp0_;
	gchar* result;
	self = (DejaDupInstallEnvSnap*) base;
	_tmp0_ = g_strdup ("snap");
	result = _tmp0_;
	return result;
}

static gchar*
deja_dup_install_env_snap_real_get_debug_info (DejaDupInstallEnv* base)
{
	DejaDupInstallEnvSnap * self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* result;
	self = (DejaDupInstallEnvSnap*) base;
	_tmp0_ = g_getenv ("SNAP_REVISION");
	_tmp1_ = g_strdup_printf ("Snap Revision: %s\n", _tmp0_);
	result = _tmp1_;
	return result;
}

DejaDupInstallEnvSnap*
deja_dup_install_env_snap_construct (GType object_type)
{
	DejaDupInstallEnvSnap * self = NULL;
	self = (DejaDupInstallEnvSnap*) deja_dup_install_env_construct (object_type);
	return self;
}

DejaDupInstallEnvSnap*
deja_dup_install_env_snap_new (void)
{
	return deja_dup_install_env_snap_construct (DEJA_DUP_TYPE_INSTALL_ENV_SNAP);
}

static void
deja_dup_install_env_snap_class_init (DejaDupInstallEnvSnapClass * klass,
                                      gpointer klass_data)
{
	deja_dup_install_env_snap_parent_class = g_type_class_peek_parent (klass);
	((DejaDupInstallEnvClass *) klass)->get_name = (gchar* (*) (DejaDupInstallEnv*)) deja_dup_install_env_snap_real_get_name;
	((DejaDupInstallEnvClass *) klass)->get_debug_info = (gchar* (*) (DejaDupInstallEnv*)) deja_dup_install_env_snap_real_get_debug_info;
}

static void
deja_dup_install_env_snap_instance_init (DejaDupInstallEnvSnap * self,
                                         gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
deja_dup_install_env_snap_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DejaDupInstallEnvSnapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) deja_dup_install_env_snap_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DejaDupInstallEnvSnap), 0, (GInstanceInitFunc) deja_dup_install_env_snap_instance_init, NULL };
	GType deja_dup_install_env_snap_type_id;
	deja_dup_install_env_snap_type_id = g_type_register_static (DEJA_DUP_TYPE_INSTALL_ENV, "DejaDupInstallEnvSnap", &g_define_type_info, 0);
	return deja_dup_install_env_snap_type_id;
}

GType
deja_dup_install_env_snap_get_type (void)
{
	static gsize deja_dup_install_env_snap_type_id__once = 0;
	if (g_once_init_enter (&deja_dup_install_env_snap_type_id__once)) {
		GType deja_dup_install_env_snap_type_id;
		deja_dup_install_env_snap_type_id = deja_dup_install_env_snap_get_type_once ();
		g_once_init_leave (&deja_dup_install_env_snap_type_id__once, deja_dup_install_env_snap_type_id);
	}
	return deja_dup_install_env_snap_type_id__once;
}

