/* PrimaryMenuButton.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from PrimaryMenuButton.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */

#include <adwaita.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_PRIMARY_MENU_BUTTON (primary_menu_button_get_type ())
#define PRIMARY_MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PRIMARY_MENU_BUTTON, PrimaryMenuButton))
#define PRIMARY_MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PRIMARY_MENU_BUTTON, PrimaryMenuButtonClass))
#define IS_PRIMARY_MENU_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PRIMARY_MENU_BUTTON))
#define IS_PRIMARY_MENU_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PRIMARY_MENU_BUTTON))
#define PRIMARY_MENU_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PRIMARY_MENU_BUTTON, PrimaryMenuButtonClass))

typedef struct _PrimaryMenuButton PrimaryMenuButton;
typedef struct _PrimaryMenuButtonClass PrimaryMenuButtonClass;
typedef struct _PrimaryMenuButtonPrivate PrimaryMenuButtonPrivate;
enum  {
	PRIMARY_MENU_BUTTON_0_PROPERTY,
	PRIMARY_MENU_BUTTON_NUM_PROPERTIES
};
static GParamSpec* primary_menu_button_properties[PRIMARY_MENU_BUTTON_NUM_PROPERTIES];

struct _PrimaryMenuButton {
	AdwBin parent_instance;
	PrimaryMenuButtonPrivate * priv;
};

struct _PrimaryMenuButtonClass {
	AdwBinClass parent_class;
};

static gpointer primary_menu_button_parent_class = NULL;

VALA_EXTERN GType primary_menu_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PrimaryMenuButton, g_object_unref)
VALA_EXTERN PrimaryMenuButton* primary_menu_button_new (void);
VALA_EXTERN PrimaryMenuButton* primary_menu_button_construct (GType object_type);
static GType primary_menu_button_get_type_once (void);

PrimaryMenuButton*
primary_menu_button_construct (GType object_type)
{
	PrimaryMenuButton * self = NULL;
	self = (PrimaryMenuButton*) g_object_new (object_type, NULL);
	return self;
}

PrimaryMenuButton*
primary_menu_button_new (void)
{
	return primary_menu_button_construct (TYPE_PRIMARY_MENU_BUTTON);
}

static void
primary_menu_button_class_init (PrimaryMenuButtonClass * klass,
                                gpointer klass_data)
{
	primary_menu_button_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/DejaDup/PrimaryMenuButton.ui");
}

static void
primary_menu_button_instance_init (PrimaryMenuButton * self,
                                   gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

 G_GNUC_NO_INLINE static GType
primary_menu_button_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (PrimaryMenuButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) primary_menu_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PrimaryMenuButton), 0, (GInstanceInitFunc) primary_menu_button_instance_init, NULL };
	GType primary_menu_button_type_id;
	primary_menu_button_type_id = g_type_register_static (adw_bin_get_type (), "PrimaryMenuButton", &g_define_type_info, 0);
	return primary_menu_button_type_id;
}

GType
primary_menu_button_get_type (void)
{
	static gsize primary_menu_button_type_id__once = 0;
	if (g_once_init_enter (&primary_menu_button_type_id__once)) {
		GType primary_menu_button_type_id;
		primary_menu_button_type_id = primary_menu_button_get_type_once ();
		g_once_init_leave (&primary_menu_button_type_id__once, primary_menu_button_type_id);
	}
	return primary_menu_button_type_id__once;
}

